==> ndu-1.1.1.tgz: package/lib/cli.js <==
/*
 * Copyright (c) 2016, Groupon
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
'use strict';
const generateDependencyStats = require('./ndu');
const writePageFromStats = require('./page');
const startServer = require('./server');

const minimist = require('minimist');
const open = require('opener');

const argv = minimist(process.argv.slice(2), {
  boolean: ['open', 'json'],
  alias: { 'O': 'open' },
});

function printStats(stats) {
  if (argv.json) {
    return process.stdout.write(JSON.stringify(stats) + '\n');
  } else if (argv.open) {
    return startServer(stats)
      .then(url => {
        process.stdout.write(`Opening ${url}\n`);
        return url;
      })
      .then(open);
  }
  return writePageFromStats(stats, process.stdout);
}

generateDependencyStats()
  .then(printStats)
  .then(null, error => {
    process.nextTick(() => { throw error; });
  });

==> ndu-1.1.4.tgz: package/lib/cli.js <==
/*
 * Copyright (c) 2016, Groupon
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

'use strict';

const generateDependencyStats = require('./ndu');
const writePageFromStats = require('./page');
const startServer = require('./server');

const minimist = require('minimist');
const open = require('opener');

const argv = minimist(process.argv.slice(2), {
  boolean: ['open', 'json'],
  alias: { O: 'open' },
});

function printStats(stats) {
  if (argv.json) {
    return process.stdout.write(`${JSON.stringify(stats)}\n`);
  } else if (argv.open) {
    return startServer(stats)
      .then(url => {
        process.stdout.write(`Opening ${url}\n`);
        return url;
      })
      .then(open);
  }
  return writePageFromStats(stats, process.stdout);
}

generateDependencyStats()
  .then(printStats)
  .then(null, error => {
    process.nextTick(() => {
      throw error;
    });
  });
